@@ -76,6 +76,41 @@ def keepCurrentPage():
     )
 
 
+def switchPage(value):
+    if type(value) == int:
+        value = driver.window_handles[value]
+    else:
+        value = str(value)
+    driver.switch_to.window(value)
+
+
+def closePage(*parList):
+    ary = []
+    for value in parList:
+        if type(value) == int:
+            value = driver.window_handles[value]
+        else:
+            value = str(value)
+        ary.append(value)
+    for value in ary:
+        driver.switch_to.window(value)
+        driver.close()
+
+
+def closePageExcept(*parList):
+    ary = []
+    for value in parList:
+        if type(value) == int:
+            value = driver.window_handles[value]
+        else:
+            value = str(value)
+        ary.append(value)
+    for value in driver.window_handles[:]:
+        if value not in ary:
+            driver.switch_to.window(value)
+            driver.close()
+
+
 def getActionChains():
     return webdriver.ActionChains(driver)
 
